;/**************************************************************************//**
; * @file     startup_LPC804.s
; * @brief    CMSIS Core Device Startup File for
; *           NXP LPC804 Device Series
; * @version  V1.0.0
; * @date     18. December 2017
; *
; * @note
; * Copyright (C) 2017 ARM Limited. All rights reserved.
; *
; * @par
; * ARM Limited (ARM) is supplying this software for use with Cortex-M
; * processor based microcontrollers.  This file can be freely distributed
; * within development tools that are supporting such ARM based processors.
; *
; * @par
; * THIS SOFTWARE IS PROVIDED "AS IS".  NO WARRANTIES, WHETHER EXPRESS, IMPLIED
; * OR STATUTORY, INCLUDING, BUT NOT LIMITED TO, IMPLIED WARRANTIES OF
; * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE APPLY TO THIS SOFTWARE.
; * ARM SHALL NOT, IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL, OR
; * CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
; *
; ******************************************************************************/

; *------- <<< Use Configuration Wizard in Context Menu >>> ------------------

; <h> Stack Configuration
;   <o> Stack Size (in Bytes) <0x0-0xFFFFFFFF:8>
; </h>

Stack_Size      EQU     0x00000100

                AREA    STACK, NOINIT, READWRITE, ALIGN=3
Stack_Mem       SPACE   Stack_Size
__initial_sp


; <h> Heap Configuration
;   <o>  Heap Size (in Bytes) <0x0-0xFFFFFFFF:8>
; </h>

Heap_Size       EQU     0x00000000

                IF      Heap_Size != 0                ; Heap is provided
                AREA    HEAP, NOINIT, READWRITE, ALIGN=3
__heap_base
Heap_Mem        SPACE   Heap_Size
__heap_limit
                ELSE
                IMPORT __use_no_heap                  ; generate warning if heap is required
                ENDIF


                PRESERVE8
                THUMB


; Vector Table Mapped to Address 0 at Reset

                AREA    RESET, DATA, READONLY
                EXPORT  __Vectors

__Vectors       DCD     __initial_sp              ;       Top of Stack
                DCD     Reset_Handler             ;       Reset Handler
                DCD     NMI_Handler               ;       NMI Handler
                DCD     HardFault_Handler         ;       Hard Fault Handler
                DCD     0                         ;       Reserved
                DCD     0                         ;       Reserved
                DCD     0                         ;       Reserved
                DCD     0                         ;       Reserved
                DCD     0                         ;       Reserved
                DCD     0                         ;       Reserved
                DCD     0                         ;       Reserved
                DCD     SVC_Handler               ;       SVCall Handler
                DCD     0                         ;       Reserved
                DCD     0                         ;       Reserved
                DCD     PendSV_Handler            ;       PendSV Handler
                DCD     SysTick_Handler           ;       SysTick Handler

                ; External Interrupts
                DCD     SPI0_IRQHandler           ; 16+ 0 SPI0 interrupt
                DCD     0                         ; 16+ 1 Reserved
                DCD     DAC0_IRQHandler           ; 16+ 2 DAC0 interrupt
                DCD     UART0_IRQHandler          ; 16+ 3 USART0 interrupt
                DCD     UART1_IRQHandler          ; 16+ 4 USART1 interrupt
                DCD     0                         ; 16+ 5 Reserved
                DCD     0                         ; 16+ 6 Reserved
                DCD     I2C1_IRQHandler           ; 16+ 7 I2C1 interrupt
                DCD     I2C0_IRQHandler           ; 16+ 8 I2C0 interrupt
                DCD     0                         ; 16+ 9 Reserved
                DCD     MRT_IRQHandler            ; 16+10 Multi-rate timer interrupt
                DCD     CMP_IRQHandler            ; 16+11 Analog comparator interrupt
                DCD     WDT_IRQHandler            ; 16+12 Windowed watchdog timer interrupt
                DCD     BOD_IRQHandler            ; 16+13 BOD interrupts
                DCD     FLASH_IRQHandler          ; 16+14 flash interrupt
                DCD     WKT_IRQHandler            ; 16+15 Self-wake-up timer interrupt
                DCD     ADC_SEQA_IRQHandler       ; 16+16 ADC sequence A completion
                DCD     ADC_SEQB_IRQHandler       ; 16+17 ADC sequence B completion
                DCD     ADC_THCMP_IRQHandler      ; 16+18 ADC threshold compare
                DCD     ADC_OVR_IRQHandler        ; 16+19 ADC overrun
                DCD     0                         ; 16+20 Reserved
                DCD     0                         ; 16+21 Reserved
                DCD     0                         ; 16+22 Reserved
                DCD     CT32B0_IRQHandler         ; 16+23 Timer interrupt
                DCD     PININT0_IRQHandler        ; 16+24 Pin interrupt 0 or pattern match engine slice 0 interrupt
                DCD     PININT1_IRQHandler        ; 16+25 Pin interrupt 1 or pattern match engine slice 1 interrupt
                DCD     PININT2_IRQHandler        ; 16+26 Pin interrupt 2 or pattern match engine slice 2 interrupt
                DCD     PININT3_IRQHandler        ; 16+27 Pin interrupt 3 or pattern match engine slice 3 interrupt
                DCD     PININT4_IRQHandler        ; 16+28 Pin interrupt 4 or pattern match engine slice 4 interrupt
                DCD     PININT5_IRQHandler        ; 16+29 Pin interrupt 5 or pattern match engine slice 5 interrupt
                DCD     PININT6_IRQHandler        ; 16+30 Pin interrupt 6 or pattern match engine slice 6 interrupt
                DCD     PININT7_IRQHandler        ; 16+31 Pin interrupt 7 or pattern match engine slice 7 interrupt

; <h> Code Read Protection
;   <o> Code Read Protection  <0xFFFFFFFF=>CRP Disabled
;                             <0x12345678=>CRP Level 1
;                             <0x87654321=>CRP Level 2
;                             <0x43218765=>CRP Level 3 (ARE YOU SURE?)
;                             <0x4E697370=>NO ISP (ARE YOU SURE?)
; </h>
                IF      :LNOT::DEF:NO_CRP
                AREA    |.ARM.__at_0x02FC|, CODE, READONLY
                DCD     0xFFFFFFFF
                ENDIF

                AREA    |.text|, CODE, READONLY


; Reset Handler

Reset_Handler   PROC
                EXPORT  Reset_Handler             [WEAK]
                IMPORT  SystemInit
                IMPORT  __main
                LDR     R0, =SystemInit
                BLX     R0
                LDR     R0, =__main
                BX      R0
                ENDP


; Dummy Exception Handlers (infinite loops which can be modified)
NMI_Handler     PROC
                EXPORT  NMI_Handler               [WEAK]
                B       .
                ENDP
HardFault_Handler\
                PROC
                EXPORT  HardFault_Handler         [WEAK]
                B       .
                ENDP
SVC_Handler     PROC
                EXPORT  SVC_Handler               [WEAK]
                B       .
                ENDP
PendSV_Handler  PROC
                EXPORT  PendSV_Handler            [WEAK]
                B       .
                ENDP
SysTick_Handler PROC
                EXPORT  SysTick_Handler           [WEAK]
                B       .
                ENDP

Default_Handler PROC

                EXPORT  SPI0_IRQHandler           [WEAK]
                EXPORT  DAC0_IRQHandler           [WEAK]
                EXPORT  UART0_IRQHandler          [WEAK]
                EXPORT  UART1_IRQHandler          [WEAK]
                EXPORT  I2C1_IRQHandler           [WEAK]
                EXPORT  I2C0_IRQHandler           [WEAK]
                EXPORT  MRT_IRQHandler            [WEAK]
                EXPORT  CMP_IRQHandler            [WEAK]
                EXPORT  WDT_IRQHandler            [WEAK]
                EXPORT  BOD_IRQHandler            [WEAK]
                EXPORT  FLASH_IRQHandler          [WEAK]
                EXPORT  WKT_IRQHandler            [WEAK]
                EXPORT  ADC_SEQA_IRQHandler       [WEAK]
                EXPORT  ADC_SEQB_IRQHandler       [WEAK]
                EXPORT  ADC_THCMP_IRQHandler      [WEAK]
                EXPORT  ADC_OVR_IRQHandler        [WEAK]
                EXPORT  CT32B0_IRQHandler         [WEAK]
                EXPORT  PININT0_IRQHandler        [WEAK]
                EXPORT  PININT1_IRQHandler        [WEAK]
                EXPORT  PININT2_IRQHandler        [WEAK]
                EXPORT  PININT3_IRQHandler        [WEAK]
                EXPORT  PININT4_IRQHandler        [WEAK]
                EXPORT  PININT5_IRQHandler        [WEAK]
                EXPORT  PININT6_IRQHandler        [WEAK]
                EXPORT  PININT7_IRQHandler        [WEAK]

SPI0_IRQHandler
DAC0_IRQHandler
UART0_IRQHandler
UART1_IRQHandler
I2C1_IRQHandler
I2C0_IRQHandler
MRT_IRQHandler
CMP_IRQHandler
WDT_IRQHandler
BOD_IRQHandler
FLASH_IRQHandler
WKT_IRQHandler
ADC_SEQA_IRQHandler
ADC_SEQB_IRQHandler
ADC_THCMP_IRQHandler
ADC_OVR_IRQHandler
CT32B0_IRQHandler
PININT0_IRQHandler
PININT1_IRQHandler
PININT2_IRQHandler
PININT3_IRQHandler
PININT4_IRQHandler
PININT5_IRQHandler
PININT6_IRQHandler
PININT7_IRQHandler

                B       .

                ENDP


                ALIGN


; User setup Stack & Heap

                IF      :LNOT::DEF:__MICROLIB
                IMPORT  __use_two_region_memory
                ENDIF

                EXPORT  __initial_sp
                IF      Heap_Size != 0                ; Heap is provided
                EXPORT  __heap_base
                EXPORT  __heap_limit
                ENDIF

                END
